@@ -1,22 +1,8 @@
 /*
- *   Copyright 2014 Martin Gräßlin <mgraesslin@kde.org>
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Lesser General Public
- *   License as published by the Free Software Foundation; either
- *   version 2.1 of the License, or (at your option) version 3, or any
- *   later version accepted by the membership of KDE e.V. (or its
- *   successor approved by the membership of KDE e.V.), which shall
- *   act as a proxy defined in Section 6 of version 3 of the license.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Lesser General Public License for more details.
- *
- *   You should have received a copy of the GNU Lesser General Public
- *   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "kwindowsystem.h"
 #include "kwindowsystem_dummy_p.h"
 #include "kwindowsystemplugininterface_p.h"
@@ -33,11 +19,10 @@
 #endif
 #include <QWindow>
 #if KWINDOWSYSTEM_HAVE_X11
-#include <QX11Info>
 #endif
 
-//QPoint and QSize all have handy / operators which are useful for scaling, positions and sizes for high DPI support
-//QRect does not, so we create one for internal purposes within this class
+// QPoint and QSize all have handy / operators which are useful for scaling, positions and sizes for high DPI support
+// QRect does not, so we create one for internal purposes within this class
 inline QRect operator/(const QRect &rectangle, qreal factor)
 {
     return QRect(rectangle.topLeft() / factor, rectangle.size() / factor);
@@ -46,17 +31,19 @@ inline QRect operator/(const QRect &rectangle, qreal factor)
 class KWindowSystemStaticContainer
 {
 public:
-    KWindowSystemStaticContainer() {
+    KWindowSystemStaticContainer()
+    {
         d.reset(KWindowSystemPluginWrapper::self().createWindowSystem());
 
         if (QCoreApplication::instance()) {
             kwm.moveToThread(QCoreApplication::instance()->thread());
         }
     }
-    KWindowSystemPrivate *xcbPlugin() {
+    KWindowSystemPrivate *xcbPlugin()
+    {
         if (xcbPrivate.isNull()) {
             QPluginLoader loader(QStringLiteral(XCB_PLUGIN_PATH));
-            QScopedPointer<KWindowSystemPluginInterface> xcbPlugin(qobject_cast< KWindowSystemPluginInterface* >(loader.instance()));
+            QScopedPointer<KWindowSystemPluginInterface> xcbPlugin(qobject_cast<KWindowSystemPluginInterface *>(loader.instance()));
             if (!xcbPlugin.isNull()) {
                 xcbPrivate.reset(xcbPlugin->createWindowSystem());
             }
@@ -270,9 +257,19 @@ void KWindowSystemPrivateDummy::setUserTime(WId win, long time)
     Q_UNUSED(time)
 }
 
-void KWindowSystemPrivateDummy::setExtendedStrut(WId win, int left_width, int left_start, int left_end,
-                                                 int right_width, int right_start, int right_end, int top_width, int top_start, int top_end,
-                                                 int bottom_width, int bottom_start, int bottom_end)
+void KWindowSystemPrivateDummy::setExtendedStrut(WId win,
+                                                 int left_width,
+                                                 int left_start,
+                                                 int left_end,
+                                                 int right_width,
+                                                 int right_start,
+                                                 int right_end,
+                                                 int top_width,
+                                                 int top_start,
+                                                 int top_end,
+                                                 int bottom_width,
+                                                 int bottom_start,
+                                                 int bottom_end)
 {
     Q_UNUSED(win)
     Q_UNUSED(left_width)
@@ -640,15 +637,35 @@ void KWindowSystem::setUserTime(WId win, long time)
     d->setUserTime(win, time);
 }
 
-void KWindowSystem::setExtendedStrut(WId win, int left_width, int left_start, int left_end,
-                                     int right_width, int right_start, int right_end, int top_width, int top_start, int top_end,
-                                     int bottom_width, int bottom_start, int bottom_end)
+void KWindowSystem::setExtendedStrut(WId win,
+                                     int left_width,
+                                     int left_start,
+                                     int left_end,
+                                     int right_width,
+                                     int right_start,
+                                     int right_end,
+                                     int top_width,
+                                     int top_start,
+                                     int top_end,
+                                     int bottom_width,
+                                     int bottom_start,
+                                     int bottom_end)
 {
     Q_D(KWindowSystem);
     const qreal dpr = qApp->devicePixelRatio();
-    d->setExtendedStrut(win, left_width * dpr, left_start * dpr, left_end * dpr,
-                        right_width * dpr, right_start * dpr, right_end * dpr, top_width * dpr, top_start * dpr, top_end * dpr,
-                        bottom_width * dpr, bottom_start * dpr, bottom_end * dpr);
+    d->setExtendedStrut(win,
+                        left_width * dpr,
+                        left_start * dpr,
+                        left_end * dpr,
+                        right_width * dpr,
+                        right_start * dpr,
+                        right_end * dpr,
+                        top_width * dpr,
+                        top_start * dpr,
+                        top_end * dpr,
+                        bottom_width * dpr,
+                        bottom_start * dpr,
+                        bottom_end * dpr);
 }
 
 void KWindowSystem::setStrut(WId win, int left, int right, int top, int bottom)
@@ -754,3 +771,34 @@ bool KWindowSystem::isPlatformWayland()
 {
     return platform() == Platform::Wayland;
 }
+
+void KWindowSystem::requestXdgActivationToken(QWindow *win, uint32_t serial, const QString &app_id)
+{
+    Q_D(KWindowSystem);
+    auto dv2 = dynamic_cast<KWindowSystemPrivateV2 *>(d);
+    if (!dv2) {
+        Q_EMIT KWindowSystem::self()->xdgActivationTokenArrived(serial, {});
+        return;
+    }
+    dv2->requestToken(win, serial, app_id);
+}
+
+void KWindowSystem::setCurrentXdgActivationToken(const QString &token)
+{
+    Q_D(KWindowSystem);
+    auto dv2 = dynamic_cast<KWindowSystemPrivateV2 *>(d);
+    if (!dv2) {
+        return;
+    }
+    dv2->setCurrentToken(token);
+}
+
+quint32 KWindowSystem::lastInputSerial(QWindow *window)
+{
+    Q_D(KWindowSystem);
+    auto dv2 = dynamic_cast<KWindowSystemPrivateV2 *>(d);
+    if (!dv2) {
+        return 0;
+    }
+    return dv2->lastInputSerial(window);
+}
